-- 

SET client_encoding = 'UTF8'; 
SET standard_conforming_strings = off; 
SET escape_string_warning = 'off'; 

-- 
-- Roles de login
-- 
CREATE ROLE gvh_log; 
ALTER ROLE gvh_log WITH NOSUPERUSER INHERIT NOCREATEROLE NOCREATEDB LOGIN PASSWORD 'gvh_log' VALID UNTIL 'infinity'; 

CREATE ROLE gvh; 
ALTER ROLE gvh WITH NOSUPERUSER INHERIT NOCREATEROLE NOCREATEDB LOGIN PASSWORD 'gvh' VALID UNTIL 'infinity'; 

CREATE ROLE gvh_ac; 
ALTER ROLE gvh_ac WITH NOSUPERUSER INHERIT NOCREATEROLE NOCREATEDB LOGIN PASSWORD 'gvh_ac' VALID UNTIL 'infinity';  

CREATE ROLE gvh_ae; 
ALTER ROLE gvh_ae WITH NOSUPERUSER INHERIT NOCREATEROLE NOCREATEDB LOGIN PASSWORD 'gvh_ae' VALID UNTIL 'infinity';
-- 
-- Roles de grupo
-- 
CREATE ROLE rgvh; 
ALTER ROLE rgvh WITH NOSUPERUSER INHERIT NOCREATEROLE NOCREATEDB NOLOGIN;
 
CREATE ROLE rgvh_c; 
ALTER ROLE rgvh_c WITH NOSUPERUSER INHERIT NOCREATEROLE NOCREATEDB NOLOGIN; 
-- 
-- Role memberships 
-- 
GRANT rgvh TO gvh;
GRANT rgvh TO gvh_ae; 
GRANT rgvh_c TO gvh_ac; 
-- 
-- Database creation 
-- 
CREATE DATABASE embarcacionesdb;

\connect embarcacionesdb 
 
SET client_encoding = 'UTF8'; 
SET standard_conforming_strings = off; 
SET check_function_bodies = false; 
SET client_min_messages = warning; 
SET escape_string_warning = off;

CREATE SCHEMA embarcaciones; 
ALTER SCHEMA embarcaciones OWNER TO gvh;

ALTER ROLE gvh_log SET search_path TO embarcaciones; 
ALTER ROLE gvh SET search_path TO embarcaciones;
ALTER ROLE gvh_ac SET search_path TO embarcaciones;
ALTER ROLE gvh_ae SET search_path TO embarcaciones;


CREATE PROCEDURAL LANGUAGE plpgsql; 
SET search_path = embarcaciones, pg_catalog; 
SET default_with_oids = false; 

CREATE TABLE propietario ( 
    dni character varying(13) NOT NULL, 
    nombre character varying(50) NOT NULL, 
    direccion character varying(100), 
    telefono character varying(15), 
    cuenta_bancaria character varying(23) NOT NULL, 
    observaciones text,

    CONSTRAINT propietario_pkey PRIMARY KEY (dni),
    CONSTRAINT nombreuni UNIQUE (nombre),
    CONSTRAINT cuenta_bancariauni UNIQUE (cuenta_bancaria)
); 
ALTER TABLE embarcaciones.propietario OWNER TO gvh; 


CREATE TABLE provincia ( 
    cprov character varying(5) NOT NULL, 
    dprov character varying(30) NOT NULL,

    CONSTRAINT provincia_pkey PRIMARY KEY (cprov),
    CONSTRAINT emb_dprovuni UNIQUE (dprov)
); 
ALTER TABLE embarcaciones.provincia OWNER TO gvh; 


CREATE TABLE municipio ( 
    cmun character varying(5) NOT NULL, 
    dmun character varying(30) NOT NULL, 
    provincia_cprov character varying(5) NOT NULL,

    CONSTRAINT municipio_pkey PRIMARY KEY (cmun),
    CONSTRAINT muni_dmununi UNIQUE (dmun),
    CONSTRAINT fk_municipio_provincia1 FOREIGN KEY (provincia_cprov) REFERENCES provincia(cprov)
); 
ALTER TABLE embarcaciones.municipio OWNER TO gvh; 



CREATE TABLE embarcacion ( 
    codigo character varying(10) NOT NULL, 
    matricula character varying(12) NOT NULL, 
    nombre character varying(50) NOT NULL, 
    manga double precision, 
    eslora double precision, 
    vela_motor character varying(1), 
    fecha_compra date, 
    caballaje integer, 
    propietario_dni character varying(13) NOT NULL ,

    CONSTRAINT embarcacion_pkey PRIMARY KEY (codigo),
    CONSTRAINT emb_matriculauni UNIQUE (matricula),
    CONSTRAINT emb_nombreuni UNIQUE (nombre),
    CONSTRAINT fk_embarcacion_propietario FOREIGN KEY (propietario_dni) REFERENCES propietario(dni)
); 
ALTER TABLE embarcaciones.embarcacion OWNER TO gvh; 


CREATE TABLE puerto ( 
    cpuerto character varying(5) NOT NULL, 
    dpuerto character varying(50) NOT NULL, 
    direccion character varying(50), 
    telefono character varying(20), 
    municipio_cmun character varying(5) NOT NULL,

    CONSTRAINT puerto_pkey PRIMARY KEY (cpuerto),
    CONSTRAINT puerto_dpuertouni UNIQUE (dpuerto),
    CONSTRAINT fk_puerto_municipio1 FOREIGN KEY (municipio_cmun) REFERENCES municipio(cmun)
);
ALTER TABLE embarcaciones.puerto OWNER TO gvh; 


CREATE TABLE estancia ( 
    desde timestamp without time zone NOT NULL, 
    hasta timestamp without time zone NOT NULL, 
    embarcacion_codigo character varying(10) NOT NULL, 
    puerto_cpuerto character varying(5) NOT NULL,
    id integer NOT NULL,

    CONSTRAINT estancia_pk PRIMARY KEY (id),
    CONSTRAINT fk_estancia_embarcacion1 FOREIGN KEY (embarcacion_codigo) REFERENCES embarcacion(codigo) ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT fk_estancia_puerto1 FOREIGN KEY (puerto_cpuerto) REFERENCES puerto(cpuerto) ON UPDATE CASCADE ON DELETE CASCADE
); 
ALTER TABLE embarcaciones.estancia OWNER TO gvh; 

CREATE SEQUENCE scmn_id_errlog 
    INCREMENT BY 1 
    NO MAXVALUE 
    MINVALUE 0 
    CACHE 1 
    CYCLE; 
ALTER TABLE embarcaciones.scmn_id_errlog OWNER TO gvh_log; 
SELECT pg_catalog.setval('scmn_id_errlog', 1, true); 

CREATE TABLE tcmn_errlog ( 
    iderror numeric(9,0) NOT NULL, 
    aplicacion character varying(10) NOT NULL, 
    modulo character varying(10), 
    version character varying(10) NOT NULL, 
    usuario character varying(30) NOT NULL, 
    fecha timestamp without time zone NOT NULL, 
    tipo numeric(2,0) NOT NULL, 
    mensaje text NOT NULL,

    CONSTRAINT tcmn_errlog_pkey PRIMARY KEY (iderror)
); 
ALTER TABLE embarcaciones.tcmn_errlog OWNER TO gvh_log; 


INSERT INTO propietario VALUES ('11111111H', 'Ignacio Santos Gaudioso', 'C/Visitación 2 - Benetusser', '(+34)-666000111', '1111 1111 11 1111111111', 'bla bla bla bla'); 
INSERT INTO propietario VALUES ('00000012A', 'Antonio Felix', 'C/Lérida 21 - Foyos', '(+34)-666000222', '2222 2222 22 2222222222', 'bla bla bla bla'); 
INSERT INTO propietario VALUES ('58784419J', 'Verónica Navarro', 'C/Bilbao 10 - Valencia', '(+34)-666000333', '3333 2222 11 1232425222', 'bla bla bla bla'); 
INSERT INTO propietario VALUES ('63589735B', 'David Pascual', 'C/Sagunto 1 - Valencia', '(+34)-666000444', '2552 5252 65 2652232133', 'bla bla bla bla'); 

INSERT INTO embarcacion VALUES ('1', 'VA-3-128-05', 'Lébole', 1.6, 3.2, 'm', '2009-12-12', 10, '11111111H'); 
INSERT INTO embarcacion VALUES ('2', 'AL-2-232-06', 'Mar', 2.2, 2.6, 'm', '2011-01-20', 10, '00000012A'); 
INSERT INTO embarcacion VALUES ('3', 'VA-3-100-10', 'Aitana', 2.3, 3.3, 'v', '2010-10-21', 9, '58784419J'); 
INSERT INTO embarcacion VALUES ('4', 'VA-1-095-01', 'Luca', 2.6, 3, 'v', '2010-06-11', 9, '63589735B');

INSERT INTO provincia VALUES ('03', 'ALICANTE');
INSERT INTO provincia VALUES ('12', 'CASTELLÓN');
INSERT INTO provincia VALUES ('46', 'VALENCIA');

INSERT INTO municipio VALUES ('03739', 'Jávea', '03'); 
INSERT INTO municipio VALUES ('03700', 'Dénia', '03'); 
INSERT INTO municipio VALUES ('46520', 'Puerto de Sagunto', '46'); 
INSERT INTO municipio VALUES ('46730', 'Gandía', '46'); 
INSERT INTO municipio VALUES ('12579', 'Alcocebre', '12'); 
INSERT INTO municipio VALUES ('12530', 'Burriana', '12'); 

INSERT INTO puerto VALUES ('1', 'El portet de Dénia', 'Avd. Marítimo', '963252654', '03700'); 
INSERT INTO puerto VALUES ('2', 'Puerto Jávea', 'Avd. Mediterráneo', '963652636', '03739'); 
INSERT INTO puerto VALUES ('3', 'El port de Sagunt', 'Avd. Al Mar', '963595444', '46520'); 
INSERT INTO puerto VALUES ('4', 'Puerto Deportivo Las Fuentes', 'Avd. Castellón', '961525444', '12579'); 
INSERT INTO puerto VALUES ('5', 'Club de mar Burriananova', 'Paseo Al Mar', '961095184', '12530'); 
INSERT INTO puerto VALUES ('6', 'Puerto del Real Club Náutico de Gandía', 'Paseo Marítimo Neptuno', '962841050', '46730'); 

INSERT INTO estancia VALUES ('2011-01-13 00:00:00', '2011-01-20 00:00:00', '2', '1', 1); 
INSERT INTO estancia VALUES ('2011-02-13 00:00:00', '2011-02-14 00:00:00', '2', '1', 2); 


REVOKE ALL ON SCHEMA embarcaciones FROM PUBLIC; 
REVOKE ALL ON SCHEMA embarcaciones FROM gvh; 
GRANT ALL ON SCHEMA embarcaciones TO gvh;
GRANT USAGE ON SCHEMA embarcaciones TO gvh_log; 
GRANT USAGE ON SCHEMA embarcaciones TO rgvh; 
GRANT USAGE ON SCHEMA embarcaciones TO rgvh_c;

REVOKE ALL ON TABLE embarcacion FROM PUBLIC; 
REVOKE ALL ON TABLE embarcacion FROM gvh; 
GRANT ALL ON TABLE embarcacion TO gvh; 
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE embarcacion TO rgvh; 
GRANT SELECT ON TABLE embarcacion TO rgvh_c; 

REVOKE ALL ON TABLE estancia FROM PUBLIC; 
REVOKE ALL ON TABLE estancia FROM gvh; 
GRANT ALL ON TABLE estancia TO gvh; 
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE estancia TO rgvh; 
GRANT SELECT ON TABLE estancia TO rgvh_c; 

REVOKE ALL ON TABLE municipio FROM PUBLIC; 
REVOKE ALL ON TABLE municipio FROM gvh; 
GRANT ALL ON TABLE municipio TO gvh; 
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE municipio TO rgvh; 
GRANT SELECT ON TABLE municipio TO rgvh_c; 

REVOKE ALL ON TABLE propietario FROM PUBLIC; 
REVOKE ALL ON TABLE propietario FROM gvh; 
GRANT ALL ON TABLE propietario TO gvh; 
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE propietario TO rgvh; 
GRANT SELECT ON TABLE propietario TO rgvh_c; 

REVOKE ALL ON TABLE provincia FROM PUBLIC; 
REVOKE ALL ON TABLE provincia FROM gvh; 
GRANT ALL ON TABLE provincia TO gvh; 
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE provincia TO rgvh; 
GRANT SELECT ON TABLE provincia TO rgvh_c; 

REVOKE ALL ON TABLE puerto FROM PUBLIC; 
REVOKE ALL ON TABLE puerto FROM gvh; 
GRANT ALL ON TABLE puerto TO gvh; 
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE puerto TO rgvh; 
GRANT SELECT ON TABLE puerto TO rgvh_c; 

REVOKE ALL ON SEQUENCE scmn_id_errlog FROM PUBLIC; 
REVOKE ALL ON SEQUENCE scmn_id_errlog FROM gvh_log; 
GRANT ALL ON SEQUENCE scmn_id_errlog TO gvh_log;

REVOKE ALL ON TABLE tcmn_errlog FROM PUBLIC; 
REVOKE ALL ON TABLE tcmn_errlog FROM gvh_log; 
GRANT ALL ON TABLE tcmn_errlog TO gvh_log; 
